@@ -1,7 +1,10 @@
 
+
+
 import numpy as np
 
 from functools import lru_cache, wraps
+
 #from fastcache import clru_cache
 
 
@@ -47,8 +50,8 @@ if __name__ == '__main__':
     def with_c(arr):
         return f(arr)
 
-    %time for _ in range(50): [no_c(arr) for arr in ar[np.random.rand(ar.shape[0]).argsort()]]
-    %time for _ in range(50): [with_c(arr) for arr in ar[np.random.rand(ar.shape[0]).argsort()]]
+    #%time for _ in range(50): [no_c(arr) for arr in ar[np.random.rand(ar.shape[0]).argsort()]]
+    #%time for _ in range(50): [with_c(arr) for arr in ar[np.random.rand(ar.shape[0]).argsort()]]
 
 
 
